@@ -2,16 +2,12 @@
 
 from curses import ascii
 
-from fontbro.features import FEATURES as _FEATURES_LIST
 from fontbro.flags import get_flag, set_flag
-from fontbro.unicodedata import (
-    UNICODE_BLOCKS as _UNICODE_BLOCKS,
-    UNICODE_SCRIPTS as _UNICODE_SCRIPTS,
-)
-from fontbro.utils import slugify
+from fontbro.subset import parse_unicodes
+from fontbro.utils import read_json, slugify
 
 from fontTools import unicodedata
-from fontTools.subset import parse_unicodes, Subsetter
+from fontTools.subset import Subsetter
 from fontTools.ttLib import TTFont, TTLibError
 from fontTools.varLib import instancer
 from fontTools.varLib.instancer import OverlapMode
@@ -21,7 +17,6 @@ import fsutil
 import itertools
 import math
 import os
-import re
 import sys
 
 
@@ -33,7 +28,7 @@ class Font(object):
     # Features:
     # https://docs.microsoft.com/en-gb/typography/opentype/spec/featurelist
     # https://developer.mozilla.org/en-US/docs/Web/CSS/font-feature-settings
-    _FEATURES_LIST = _FEATURES_LIST
+    _FEATURES_LIST = read_json("data/features.json")
     _FEATURES_BY_TAG = {feature["tag"]: feature for feature in _FEATURES_LIST}
 
     # Formats:
@@ -128,6 +123,10 @@ class Font(object):
     }
     _STYLE_FLAGS_KEYS = _STYLE_FLAGS.keys()
 
+    # Unicode blocks/scripts data:
+    _UNICODE_BLOCKS = read_json("data/unicode-blocks.json")
+    _UNICODE_SCRIPTS = read_json("data/unicode-scripts.json")
+
     # Variable Axes:
     _VARIABLE_AXES = [
         {"tag": "ital", "name": "Italic"},
@@ -485,7 +484,7 @@ class Font(object):
             }
             self._populate_unicode_items_set(items, items_cache, item)
         blocks = self._get_unicode_items_set_with_coverage(
-            _UNICODE_BLOCKS, items, coverage_threshold=coverage_threshold
+            self._UNICODE_BLOCKS, items, coverage_threshold=coverage_threshold
         )
         return blocks
 
@@ -526,7 +525,7 @@ class Font(object):
             }
             self._populate_unicode_items_set(items, items_cache, item)
         scripts = self._get_unicode_items_set_with_coverage(
-            _UNICODE_SCRIPTS, items, coverage_threshold=coverage_threshold
+            self._UNICODE_SCRIPTS, items, coverage_threshold=coverage_threshold
         )
         return scripts
 
@@ -910,19 +909,6 @@ class Font(object):
                 assert isinstance(value, bool)
                 self.set_style_flag(key, value)
 
-    @staticmethod
-    def _get_unicodes(unicodes):
-        unicodes = unicodes or ""
-        if isinstance(unicodes, (list, set, tuple)):
-            unicodes = ",".join(list(set(unicodes)))
-        # replace possible — ‐ − (&mdash; &dash; &minus;) with -
-        # remove U+ and \u if present
-        unicodes = re.sub(r"[\—\‐\−]", "-", unicodes)
-        unicodes = re.sub(r"(U\+)|(\\u)", "", unicodes)
-        unicodes = parse_unicodes(unicodes)
-        # print(unicodes)
-        return unicodes
-
     def subset(self, unicodes="", glyphs=[], text="", **options):
         """
         Subsets the font using the given options (unicodes or glyphs or text),
@@ -944,7 +930,7 @@ class Font(object):
                 "Subsetting requires at least one of the following args: unicode,"
                 " glyphs, text."
             )
-        unicodes = self._get_unicodes(unicodes)
+        unicodes = parse_unicodes(unicodes)
         subs_args = {"unicodes": unicodes, "glyphs": glyphs, "text": text}
         # https://github.com/fonttools/fonttools/blob/main/Lib/fontTools/subset/__init__.py
         subs = Subsetter(**options)
